<?php

/**
 * Favicon notifications
 *
 * @author emanuele
 * @license   BSD http://opensource.org/licenses/BSD-3-Clause
 *
 * @version 0.0.1
 */

class Faviconotif_Integrate
{
	protected static $_valid_types = array(
		'circle',
		'rectangle',
	);
	protected static $_valid_positions = array(
		'up',
		'down',
		'left',
		'upleft',
	);
	protected static $_valid_styles = array(
		'normal',
		'italic',
		'oblique',
		'bold',
		'bolder',
		'lighter',
		100, 200, 300, 400, 500, 600, 700, 800, 900
	);

	public static function integrate_load_theme()
	{
		loadJavascriptFile('favico-0.3.7.min.js');
	}

	public static function integrate_user_info()
	{
		global $user_info, $modSettings/*, $options*/;

		$notif_opt = array();
		$rules = array(
			'faviconotif_bgColor',
			'faviconotif_textColor',
			'faviconotif_type',
			'faviconotif_position',
			'faviconotif_fontStyle',
		);
		foreach ($rules as $key)
		{
			if (self::settingExists($key))
				$notif_opt[] = '
					' . JavaScriptEscape(str_replace('faviconotif_', '', $key)) . ': ' . JavaScriptEscape($modSettings[$key]);
		}

		if (!empty($modSettings['mentions_enabled']) /*&& $options['faviconotif_kind'] === 1*/ && !empty($user_info['mentions']))
		{
			addInlineJavascript('
			$(document).ready(function() {
				var mentions = new Favico({
					animation: \'none\'' . (!empty($notif_opt) ? ',' . implode(',', $notif_opt) : '') . '
				});
				mentions.badge(' . $user_info['mentions'] . ');
			});', true);
		}
// 		if ($options['faviconotif_kind'] === 2 && !empty($user_info['unread_messages']))
// 		{
// 			addInlineJavascript('
// 			$(document).ready(function() {
// 				var pms=new Favico({
// 					animation: \'none\'' . (!empty($notif_opt) ? ',' . implode(',', $notif_opt) : '') . '
// 				});
// 				pms.badge(' . $user_info['unread_messages'] . ');
// 			});', true);
// 		}
	}

	protected function settingExists($key)
	{
		global $modSettings;
		return isset($modSettings[$key]) && $modSettings[$key] !== '';
	}

	public static function integrate_general_mod_settings(&$config_vars)
	{
		global $txt;

		loadLanguage('Faviconotif');

		$types = array();
		foreach (self::$_valid_types as $val)
			$types[$val] = $txt['faviconotif_shape_' . $val];
		$positions = array();
		foreach (self::$_valid_positions as $val)
			$positions[$val] = $txt['faviconotif_' . $val];
		$styles = array();
		foreach (self::$_valid_styles as $val)
			$styles[$val] = isset($txt['faviconotif_style_' . $val]) ? $txt['faviconotif_style_' . $val] : $val;

		$config_vars[] = array('title', 'faviconotif_title');
		$config_vars[] = array(
			'select',
			'faviconotif_type',
			$types
		);
		$config_vars[] = array(
			'select',
			'faviconotif_position',
			$positions
		);
		$config_vars[] = array('text', 'faviconotif_bgColor');
		$config_vars[] = array('text', 'faviconotif_textColor');
		$config_vars[] = array(
			'select',
			'faviconotif_fontStyle',
			$styles
		);
// 		$config_vars[] = array('check', 'faviconotif_probe_periodically', 'helptext' => $txt['faviconotif_probe_periodically_desc']);
	}

	public static function integrate_save_general_mod_settings()
	{
		global $modSettings;

		require_once(SUBSDIR . '/DataValidator.class.php');

		$validator = new Data_Validator();
		$validation_rules = array(
			'faviconotif_bgColor' => 'valid_color',
			'faviconotif_textColor' => 'valid_color',
			'faviconotif_type' => 'contains[' . implode(',', self::$_valid_types) . ']',
			'faviconotif_position' => 'contains[' . implode(',', self::$_valid_positions) . ']',
			'faviconotif_fontStyle' => 'contains[' . implode(',', self::$_valid_styles) . ']',
		);

		// Cleanup the inputs! :D
		$validator->validation_rules($validation_rules);
		$validator->validate($_POST);
		foreach ($validation_rules as $key => $val)
		{
			if (empty($validator->validation_errors($key)))
				$_POST[$key] = $validator->{$key};
			else
				$_POST[$key] = !empty($_POST[$key]) && isset($modSettings[$key]) ? $modSettings[$key] : '';
		}
	}

	public function integrate_credits(&$credits)
	{
		$credits['credits_software_graphics']['software'][] = '<a href="http://lab.ejci.net/favico.js/">favico.js</a> | &copy; Miroslav Magda | Licensed under <a href="https://github.com/ejci/favico.js/blob/0.3.7/MIT-LICENSE.txt">the MIT license</a>';
	}
}